@@ -1,4 +1,5 @@
-"abc" =~ /b/;
+$_ = "abc";
+/b/;
 
 $DB::single = 1;
 
